==> tencentcloud-sdk-java-3.1.209-sources.jar: com/tencentcloudapi/monitor/v20180724/models/InstanceGroups.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.monitor.v20180724.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class InstanceGroups extends AbstractModel{

    /**
    * 实例组 Id
    */
    @SerializedName("Id")
    @Expose
    private Long Id;

    /**
    * 实例组名称
    */
    @SerializedName("Name")
    @Expose
    private String Name;

    /**
     * Get 实例组 Id 
     * @return Id 实例组 Id
     */
    public Long getId() {
        return this.Id;
    }

    /**
     * Set 实例组 Id
     * @param Id 实例组 Id
     */
    public void setId(Long Id) {
        this.Id = Id;
    }

    /**
     * Get 实例组名称 
     * @return Name 实例组名称
     */
    public String getName() {
        return this.Name;
    }

    /**
     * Set 实例组名称
     * @param Name 实例组名称
     */
    public void setName(String Name) {
        this.Name = Name;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Id", this.Id);
        this.setParamSimple(map, prefix + "Name", this.Name);

    }
}

==> tencentcloud-sdk-java-3.1.310-sources.jar: com/tencentcloudapi/monitor/v20180724/models/InstanceGroups.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.monitor.v20180724.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class InstanceGroups extends AbstractModel{

    /**
    * 实例组 Id
    */
    @SerializedName("Id")
    @Expose
    private Long Id;

    /**
    * 实例组名称
    */
    @SerializedName("Name")
    @Expose
    private String Name;

    /**
     * Get 实例组 Id 
     * @return Id 实例组 Id
     */
    public Long getId() {
        return this.Id;
    }

    /**
     * Set 实例组 Id
     * @param Id 实例组 Id
     */
    public void setId(Long Id) {
        this.Id = Id;
    }

    /**
     * Get 实例组名称 
     * @return Name 实例组名称
     */
    public String getName() {
        return this.Name;
    }

    /**
     * Set 实例组名称
     * @param Name 实例组名称
     */
    public void setName(String Name) {
        this.Name = Name;
    }

    public InstanceGroups() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public InstanceGroups(InstanceGroups source) {
        if (source.Id != null) {
            this.Id = new Long(source.Id);
        }
        if (source.Name != null) {
            this.Name = new String(source.Name);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Id", this.Id);
        this.setParamSimple(map, prefix + "Name", this.Name);

    }
}
